@@ -1,21 +1,21 @@
 ''' Tile texture manager for BlueSky Qt/OpenGL gui. '''
 import traceback
 import math
-from os import makedirs, path
 import weakref
 from collections import OrderedDict
 from urllib.request import urlopen
 from urllib.error import URLError
 import numpy as np
+import gzip
 
 try:
     from PyQt5.Qt import Qt
-    from PyQt5.QtCore import QObject, QRunnable, QThreadPool, pyqtSignal, pyqtSlot
-    from PyQt5.QtGui import QImage
+    from PyQt5.QtCore import QObject, QRunnable, QThreadPool, pyqtSignal, pyqtSlot, QT_VERSION_STR
+    from PyQt5.QtGui import QImage, qRgba
 except ImportError:
     from PyQt6.QtCore import Qt
-    from PyQt6.QtCore import QObject, QRunnable, QThreadPool, pyqtSignal, pyqtSlot
-    from PyQt6.QtGui import QImage
+    from PyQt6.QtCore import QObject, QRunnable, QThreadPool, pyqtSignal, pyqtSlot, QT_VERSION_STR
+    from PyQt6.QtGui import QImage, qRgba
 
 import bluesky as bs
 from bluesky.core import Signal
@@ -59,25 +59,39 @@ class Tile:
         self.idxx = idxx
         self.idxy = idxy
         self.ext = source[source.rfind('.'):]
+        self.ext = '.' + bs.settings.tile_sources[source]['source'][0].split('.')[-1]
 
         self.image = None
         # For the image data, check cache path first
-        fpath = path.join(bs.settings.cache_path, source, str(zoom), str(tilex))
-        fname = path.join(fpath, f'{tiley}{self.ext}')
-        if path.exists(fname):
-            self.image = QImage(fname).convertToFormat(QImage.Format.Format_ARGB32)
+        fpath = bs.resource(bs.settings.cache_path) / source / str(zoom) / str(tilex)
+        fname = fpath / f'{tiley}{self.ext}'
+        if fname.exists():
+            self.image = QImage(fname.as_posix()).convertToFormat(QImage.Format.Format_ARGB32)
         else:
             # Make sure cache directory exists
-            makedirs(fpath, exist_ok=True)
+            fpath.mkdir(parents=True, exist_ok=True)
             for url in bs.settings.tile_sources[source]['source']:
                 try:
                     url_request = urlopen(url.format(
                         zoom=zoom, x=tilex, y=tiley))
-                    data = url_request.read()
-                    self.image = QImage.fromData(
-                        data).convertToFormat(QImage.Format.Format_ARGB32)
-                    with open(fname, 'wb') as fout:
-                        fout.write(data)
+                    
+                    if url_request.status == 204:
+                        # if no content load a blank tile
+                        self.image = QImage(256, 256, QImage.Format.Format_ARGB32)
+                        self.image.fill(qRgba(255,255,255,0))
+
+                    else:
+                        data = url_request.read()
+
+                        if url_request.headers['Content-Encoding'] == 'gzip':
+                            # There is a chance that data may come as a gzip so decompress
+                            data = gzip.decompress(data)
+                                        
+                        self.image = QImage.fromData(
+                            data).convertToFormat(QImage.Format.Format_ARGB32)
+
+                        with open(fname, 'wb') as fout:
+                            fout.write(data)
                     break
                 except URLError as e:
                     print(f'Error loading {url.format(zoom=zoom, x=tilex, y=tiley)}:')
@@ -168,9 +182,11 @@ class TiledTexture(glh.Texture, metaclass=TiledTextureMeta):
 
     def create(self):
         ''' Create this texture in GPU memory. '''
+
         if self.isCreated():
             return
         super().create()
+
         # Fetch a temporary tile image to get dimensions
         tmptile = Tile(self.tilesource, 1, 1, 1, 0, 0)
         img = tmptile.image
@@ -198,9 +214,21 @@ class TiledTexture(glh.Texture, metaclass=TiledTextureMeta):
 
         idxdata = np.array(itexw * itexh *
                            [(0, 0, 0, -1)], dtype=np.int32)
-        glh.gl.glTexImage2D_alt(glh.Texture.Target.Target2D.value, 0, glh.Texture.TextureFormat.RGBA32I.value,
-                                itexw, itexh, 0, glh.Texture.PixelFormat.RGBA_Integer.value,
-                                glh.Texture.PixelType.Int32.value, idxdata.tobytes())
+        if QT_VERSION_STR[0] == '5':
+            target_value = glh.Texture.Target.Target2D
+            text_rgba_value = glh.Texture.TextureFormat.RGBA32I
+            pixel_rgba_value = glh.Texture.PixelFormat.RGBA_Integer
+            pixel_type_value = glh.Texture.PixelType.Int32
+
+        if QT_VERSION_STR[0] == '6':
+            target_value = glh.Texture.Target.Target2D.value
+            text_rgba_value = glh.Texture.TextureFormat.RGBA32I.value
+            pixel_rgba_value = glh.Texture.PixelFormat.RGBA_Integer.value
+            pixel_type_value = glh.Texture.PixelType.Int32.value
+
+        glh.gl.glTexImage2D_alt(target_value, 0, text_rgba_value,
+                                itexw, itexh, 0, pixel_rgba_value,
+                                pixel_type_value, idxdata.tobytes())
 
         self.indextexture.setWrapMode(glh.Texture.CoordinateDirection.DirectionS,
                                       glh.Texture.WrapMode.ClampToBorder)
@@ -230,10 +258,15 @@ class TiledTexture(glh.Texture, metaclass=TiledTextureMeta):
             self.on_panzoom_changed(True)
 
     def on_panzoom_changed(self, finished=False):
-        ''' Update textures whenever pan/zoom changes. '''
+        ''' Update textures whenever pan/zoom changes. 
+            
+            Arguments:
+            - finished: False when still in the process of panning/zooming.
+        '''
         # Check if textures need to be updated
         viewport = self.glsurface.viewportlatlon()
         surfwidth_px = self.glsurface.width()
+
         # First determine floating-point, hypothetical values
         # to calculate the required tile zoom level
         # floating-point number of tiles that fit in the width of the view
@@ -263,6 +296,7 @@ class TiledTexture(glh.Texture, metaclass=TiledTextureMeta):
         tilesize_latlon1 = np.abs(tile1_bottomright - tile1_topleft)
         offset_latlon1 = viewport[2:] - tile1_topleft
         tex_y1, tex_x1 = np.abs(offset_latlon1 / tilesize_latlon1) + [ny - 1, nx - 1]
+
         # Store global offset and scale for shader uniform
         self.offsetscale = np.array(
             [tex_x0, tex_y0, tex_x1 - tex_x0, tex_y1 - tex_y0], dtype=np.float32)
@@ -310,9 +344,18 @@ class TiledTexture(glh.Texture, metaclass=TiledTextureMeta):
         self.glsurface.makeCurrent()
         self.indextexture.bind(2)
 
-        glh.gl.glTexSubImage2D_alt(glh.Texture.Target.Target2D.value, 0, 0, 0, nx, ny,
-                                   glh.Texture.PixelFormat.RGBA_Integer.value,
-                                   glh.Texture.PixelType.Int32.value, data.tobytes())
+        if QT_VERSION_STR[0] == '5':
+            target_value = glh.Texture.Target.Target2D
+            pixel_rgba_value = glh.Texture.PixelFormat.RGBA_Integer
+            pixel_type_value = glh.Texture.PixelType.Int32
+
+        if QT_VERSION_STR[0] == '6':
+            target_value = glh.Texture.Target.Target2D.value
+            pixel_rgba_value = glh.Texture.PixelFormat.RGBA_Integer.value
+            pixel_type_value = glh.Texture.PixelType.Int32.value
+
+        glh.gl.glTexSubImage2D_alt(target_value, 0, 0, 0, nx, ny,
+                                  pixel_rgba_value, pixel_type_value, data.tobytes())
 
     def load_tile(self, tile):
         ''' Send loaded image data to GPU texture array.
@@ -356,9 +399,20 @@ class TiledTexture(glh.Texture, metaclass=TiledTextureMeta):
         idxdata = np.array([0, 0, 1, layer], dtype=np.int32)
         self.indextexture.bind(2)
 
-        glh.gl.glTexSubImage2D_alt(glh.Texture.Target.Target2D.value, 0, tile.idxx, tile.idxy,
-                                   1, 1, glh.Texture.PixelFormat.RGBA_Integer.value,
-                                   glh.Texture.PixelType.Int32.value, idxdata.tobytes())
+        if QT_VERSION_STR[0] == '5':
+            target_value = glh.Texture.Target.Target2D
+            pixel_rgba_value = glh.Texture.PixelFormat.RGBA_Integer
+            pixel_type_value = glh.Texture.PixelType.Int32
+
+        if QT_VERSION_STR[0] == '6':
+            target_value = glh.Texture.Target.Target2D.value
+            pixel_rgba_value = glh.Texture.PixelFormat.RGBA_Integer.value
+            pixel_type_value = glh.Texture.PixelType.Int32.value
+
+
+        glh.gl.glTexSubImage2D_alt(target_value, 0, tile.idxx, tile.idxy,
+                                   1, 1, pixel_rgba_value,
+                                   pixel_type_value, idxdata.tobytes())
 
         self.indextexture.release()
 
